@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import logging
 import os
 
@@ -11,7 +9,7 @@ class Logger(object):
         self._logger.setLevel(logging.INFO)
         formatter = logging.Formatter('%(asctime)s:%(levelname)s: %(message)s')
         ch = logging.StreamHandler()
-        level = int(os.getenv("BINTRAY_LOGGING_LEVEL", logging.INFO))
+        level = int(os.getenv("BINTRAY_LOGGING_LEVEL", logging.WARN))
         ch.setLevel(level)
         ch.setFormatter(formatter)
         self._logger.addHandler(ch)
